@@ -152,9 +152,6 @@ INVALIDPARAMETERVALUE_INVALIDLIFECYCLEHOOKID = 'InvalidParameterValue.InvalidLif
 # The notification group ID should be a numeric string.
 INVALIDPARAMETERVALUE_INVALIDNOTIFICATIONUSERGROUPID = 'InvalidParameterValue.InvalidNotificationUserGroupId'
 
-# Invalid PAI domain name type
-INVALIDPARAMETERVALUE_INVALIDPAIDOMAINNAMETYPE = 'InvalidParameterValue.InvalidPaiDomainNameType'
-
 # Invalid scheduled action ID.
 INVALIDPARAMETERVALUE_INVALIDSCHEDULEDACTIONID = 'InvalidParameterValue.InvalidScheduledActionId'
 
@@ -266,7 +263,7 @@ MISSINGPARAMETER = 'MissingParameter'
 # A parameter is missing in a specific scenario.
 MISSINGPARAMETER_INSCENARIO = 'MissingParameter.InScenario'
 
-# 
+# The `InstanceMarketOptions` parameter of the spot instance is missing.
 MISSINGPARAMETER_INSTANCEMARKETOPTIONS = 'MissingParameter.InstanceMarketOptions'
 
 # The auto scaling group is performing a scaling activity.
